@@ -23,6 +23,15 @@ def _get_user_request_info(user_id: str) -> dict:
     }
 
 
+def _execute_actions_email_request_info(user_id: str, actions: List[str], client_id: str, redirect_uri: str) -> dict:
+    return {
+        "endpoint": f"users/{user_id}/execute-actions-email",
+        "params": {"client_id": client_id, "redirect_uri": redirect_uri, "lifespan": 604800},
+        "url_key": "keycloak",
+        "json": actions
+    }
+
+
 def _update_user_request_info(user_id: str, data: dict) -> dict:
     return {
         "endpoint": f"users/{user_id}",
