@@ -58,4 +58,13 @@ class EnvironmentConfig:
     auth_config: Auth = Auth()
 
     def get_url(self, key: str = "algora") -> str:
+        """
+        Get base URL given key.
+
+        Args:
+            key (str): URL key; 'algora', 'keycloak' or 'fred'
+
+        Returns:
+            str: Base URL string
+        """
         return self.urls.get(key, self.urls["algora"])
