@@ -1,4 +1,7 @@
+"""
+Common decorators.
+"""
 from algora.common.decorators.authorization import authenticated_request, async_authenticated_request
 from algora.common.decorators.data import data_request, async_data_request
-from algora.common.decorators.provider import provider
 from algora.common.decorators.serializable import serializable
+from algora.common.decorators.source import source
