@@ -2,17 +2,15 @@
 Helper functions.
 """
 import calendar
-import dataclasses
-from datetime import datetime
+from datetime import date, time, datetime
 from functools import reduce
 from typing import Dict, Any, Union, List, Optional
 
 import pandas as pd
+import pytz
 from pandas import DataFrame, to_datetime, bdate_range
 from pandas_market_calendars import get_calendar
 
-from algora.common.type import Datetime
-
 
 def coalesce(*args):
     """
@@ -48,24 +46,6 @@ def coalesce_callables(*args):
     return None
 
 
-def dataclass_to_dict(data_cls: dataclasses.dataclass, remove_none: bool) -> dict:
-    """
-    Get all the dataclass fields (i.e. the key value pairs) and build a dict representation.
-
-    Args:
-        data_cls (dataclass): The dataclass being converted to json
-        remove_none (bool): A flag used to remove key value pairs where the value is None from the json conversion
-
-    Returns:
-        dict: A dict representation of the dataclass
-    """
-
-    def factory(data):
-        return dict(x for x in data if not (x[1] is None and remove_none))
-
-    return dict(dataclasses.asdict(data_cls, dict_factory=factory))
-
-
 def transform_one_or_many(
         data: Union[List[Dict[str, Any]], Dict[str, List[Dict[str, Any]]]],
         key: Optional[str] = None
@@ -124,28 +104,94 @@ def timestamp_to_datetime(timestamp: int) -> datetime:
         timestamp (int): Epoch timestamp in milliseconds
 
     Returns:
-        datetime: Datetime object
+        datetime: Python datetime
     """
     return datetime.fromtimestamp(timestamp / 1000)
 
 
-def date_to_timestamp(date: Datetime) -> int:
+def date_to_timestamp(as_of_date: date) -> int:
     """
-    Datetime to epoch timestamp in milliseconds.
+    Convert date to epoch timestamp in milliseconds.
 
     Args:
-        date (Datetime): Datetime
+        as_of_date (date): Python date
 
     Returns:
         int: Epoch timestamp in milliseconds
     """
-    return calendar.timegm(date.timetuple()) * 1000
+    return calendar.timegm(as_of_date.timetuple()) * 1000
 
 
-def create_dates_between(start: Datetime, end: Datetime, frequency: str = 'B') -> List[Datetime]:
+def datetime_to_timestamp(dt: datetime) -> int:
+    """
+    Convert datetime to epoch timestamp in milliseconds.
+
+    Args:
+        dt (datetime): Python datetime
+
+    Returns:
+        int: Epoch timestamp in milliseconds
+    """
+    return calendar.timegm(dt.utctimetuple()) * 1000
+
+
+def datetime_to_utc(dt: datetime) -> datetime:
+    """
+    Standardize datetime to UTC. Assume that datetime where `tzinfo=None` is already in UTC.
+
+    Args:
+        dt (datetime): Python datetime
+
+    Returns:
+        datetime: Python datetime with standardized UTC timezone (`tzinfo=None`)
+    """
+    # assume that datetime without timezone is already in UTC
+    if dt.tzinfo is None:
+        return dt
+    return dt.astimezone(pytz.utc).replace(tzinfo=None)
+
+
+def date_to_datetime(as_of_date: date, as_of_time: time = datetime.min.time()) -> datetime:
+    """
+    Convert date and optional time to datetime. NOTE: time should not contain a timezone or else offset may not be
+    correct.
+
+    Args:
+        as_of_date (date): Python date
+        as_of_time (time): Python time
+
+    Returns:
+        datetime: Python datetime
+    """
+    return datetime.combine(as_of_date, as_of_time)
+
+
+def create_dates_between(start: date, end: date, frequency: str = 'B') -> List[date]:
+    """
+    Create dates between start and end date (inclusive). Frequency used to determine which days of the week are used.
+
+    Args:
+        start (date): Python date
+        end (date): Python date
+        frequency (str): Frequency for date range
+
+    Returns:
+        List[date]: List of dates
+    """
     return [dt.date() for dt in to_datetime(bdate_range(start=start, end=end, freq=frequency).to_list())]
 
 
-def create_market_dates_between(start: Datetime, end: Datetime, name: str = 'NYSE') -> List[Datetime]:
+def create_market_dates_between(start: date, end: date, name: str = 'NYSE') -> List[date]:
+    """
+    Create dates between start and end date (inclusive) given exchange calendar.
+
+    Args:
+        start (date): Python date
+        end (date): Python date
+        name (str): Calendar name, such as 'NYSE'
+
+    Returns:
+        List[date]: List of dates
+    """
     return [dt.date() for dt in
             to_datetime(get_calendar(name).schedule(start_date=start, end_date=end).index).to_list()]
